# Release history

### 0.0.12
* Add more integration tests.
* Update b_lambda_layer_common dependency.

### 0.0.11
* Add readme.

### 0.0.10
* Add tests.

### 0.0.9
* Enable caching.

### 0.0.8
* Fix testing configuration.

### 0.0.7
* Success! Authorizer can now successfully authorize tokens.

### 0.0.6
* First attempt to verify cognito user pool JWT token.

### 0.0.5
* Still work in progress. Requests and tests work. 
* Checking the actual access token - in progress.

### 0.0.3
* Work in progress. Added integration testing files.

### 0.0.1
* Initial build.
